@@ -22,6 +22,7 @@ import os.path
 import gettext, os, sys, locale
 from accerciser.plugin import ViewportPlugin
 from accerciser.i18n import _, N_, DOMAIN
+from accerciser import node
 
 UI_FILE = os.path.join(os.path.dirname(__file__), 
                        'event_monitor.ui')
@@ -321,9 +322,10 @@ class EventMonitor(ViewportPlugin):
     @param event: The at-spi event we are inserting.
     @type event: Accessibility.Event
     '''
-    self._writeText('%s(%s, %s, %s)\n\tsource: ' % \
-                      (event.type, event.detail1, 
-                       event.detail2, event.any_data))
+    ts = int((os.times()[-1] * 10 ) % 1000)
+    self._writeText('%02.1f %s(%s, %s, %s)\n\tsource: ' % \
+                      (ts / 10, event.type, event.detail1,
+                        event.detail2, event.any_data))
     hyperlink = self._createHyperlink(event.source)
     self._writeText(str(event.source), hyperlink)
     self._writeText('\n\tapplication: ')
@@ -334,6 +336,18 @@ class EventMonitor(ViewportPlugin):
         hyperlink = self._createHyperlink(event.sender)
         self._writeText(str(event.sender), hyperlink)
     self._writeText('\n')
+    if event.type == "screen-reader:region-changed":
+        try:
+            text = event.source.queryText()
+            (x, y, width, height) = text.getRangeExtents(event.detail1, event.detail2, pyatspi.DESKTOP_COORDS)
+            if width > 0 and height > 0:
+                ah = node._HighLight(x, y, width, height,
+                                     node.FILL_COLOR, node.FILL_ALPHA,
+                                     node.BORDER_COLOR, node.BORDER_ALPHA,
+                                     2.0, 0)
+                ah.highlight(node.HL_DURATION)
+        except:
+            pass
 
   def _writeText(self, text, *tags):
     '''
